@@ -31,30 +31,24 @@ class InitSmartVerifyRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_Ip(self):
-		return self.get_body_params().get('Ip')
-
-	def set_Ip(self,Ip):
-		self.add_body_params('Ip', Ip)
-
-	def get_CertName(self):
-		return self.get_body_params().get('CertName')
-
-	def set_CertName(self,CertName):
-		self.add_body_params('CertName', CertName)
-
-	def get_Mobile(self):
-		return self.get_body_params().get('Mobile')
-
-	def set_Mobile(self,Mobile):
-		self.add_body_params('Mobile', Mobile)
-
 	def get_UserId(self):
 		return self.get_body_params().get('UserId')
 
 	def set_UserId(self,UserId):
 		self.add_body_params('UserId', UserId)
 
+	def get_CertifyId(self):
+		return self.get_body_params().get('CertifyId')
+
+	def set_CertifyId(self,CertifyId):
+		self.add_body_params('CertifyId', CertifyId)
+
+	def get_FacePictureBase64(self):
+		return self.get_body_params().get('FacePictureBase64')
+
+	def set_FacePictureBase64(self,FacePictureBase64):
+		self.add_body_params('FacePictureBase64', FacePictureBase64)
+
 	def get_Mode(self):
 		return self.get_body_params().get('Mode')
 
@@ -79,12 +73,6 @@ class InitSmartVerifyRequest(RpcRequest):
 	def set_CertType(self,CertType):
 		self.add_body_params('CertType', CertType)
 
-	def get_SceneId(self):
-		return self.get_body_params().get('SceneId')
-
-	def set_SceneId(self,SceneId):
-		self.add_body_params('SceneId', SceneId)
-
 	def get_MetaInfo(self):
 		return self.get_body_params().get('MetaInfo')
 
@@ -95,4 +83,58 @@ class InitSmartVerifyRequest(RpcRequest):
 		return self.get_body_params().get('Ocr')
 
 	def set_Ocr(self,Ocr):
-		self.add_body_params('Ocr', Ocr)
\ No newline at end of file
+		self.add_body_params('Ocr', Ocr)
+
+	def get_OssObjectName(self):
+		return self.get_body_params().get('OssObjectName')
+
+	def set_OssObjectName(self,OssObjectName):
+		self.add_body_params('OssObjectName', OssObjectName)
+
+	def get_FacePictureUrl(self):
+		return self.get_body_params().get('FacePictureUrl')
+
+	def set_FacePictureUrl(self,FacePictureUrl):
+		self.add_body_params('FacePictureUrl', FacePictureUrl)
+
+	def get_Ip(self):
+		return self.get_body_params().get('Ip')
+
+	def set_Ip(self,Ip):
+		self.add_body_params('Ip', Ip)
+
+	def get_CertName(self):
+		return self.get_body_params().get('CertName')
+
+	def set_CertName(self,CertName):
+		self.add_body_params('CertName', CertName)
+
+	def get_Mobile(self):
+		return self.get_body_params().get('Mobile')
+
+	def set_Mobile(self,Mobile):
+		self.add_body_params('Mobile', Mobile)
+
+	def get_SceneId(self):
+		return self.get_body_params().get('SceneId')
+
+	def set_SceneId(self,SceneId):
+		self.add_body_params('SceneId', SceneId)
+
+	def get_CallbackToken(self):
+		return self.get_body_params().get('CallbackToken')
+
+	def set_CallbackToken(self,CallbackToken):
+		self.add_body_params('CallbackToken', CallbackToken)
+
+	def get_OssBucketName(self):
+		return self.get_body_params().get('OssBucketName')
+
+	def set_OssBucketName(self,OssBucketName):
+		self.add_body_params('OssBucketName', OssBucketName)
+
+	def get_CallbackUrl(self):
+		return self.get_body_params().get('CallbackUrl')
+
+	def set_CallbackUrl(self,CallbackUrl):
+		self.add_body_params('CallbackUrl', CallbackUrl)
\ No newline at end of file
